@@ -7,11 +7,6 @@ import git
 
 path = os.path.expanduser('~')
 
-profile_pass = os.path.join(path,".droughty/profile.yaml")
-
-with open(profile_pass) as f:
-    lookml_config = yaml.load(f, Loader=yaml.FullLoader)
-
 def get_git_root(path):
 
         git_repo = git.Repo(path, search_parent_directories=True)
@@ -25,11 +20,18 @@ git_path = git_def_path
 
 filename = 'droughty_project.yaml'
 
+profile_filename = 'profile.yaml'
+
 droughty_project = os.path.join(git_path,filename)
 
 with open(droughty_project) as f:
     enviroment_project = yaml.load(f, Loader=yaml.FullLoader)
 
+droughty_profile = os.path.join(git_path,profile_filename)
+
+with open(droughty_profile) as f:
+    lookml_config = yaml.load(f, Loader=yaml.FullLoader)    
+
 project_value = list(enviroment_project.values())
 profile_key = list(lookml_config.keys())
 
@@ -50,10 +52,10 @@ for key,value in enviroment_project.items():
 
             if warehouse_name == 'big_query':
 
-                service_account_path = lookml_config[value]['key_file']
+                service_account_path = ['DBT_GOOGLE_BIGQUERY_KEYFILE_DEV']
 
                 warehouse_name =  lookml_config[value]['warehouse_name']
-                project_name =  lookml_config[value]['project_name']
+                project_name =  ['DBT_GOOGLE_PROJECT_DEV']
 
                 service_account = service_account.Credentials.from_service_account_file(
                     service_account_path,
