@@ -10,15 +10,11 @@ from jinjasql import JinjaSql
 from six import string_types
 from copy import deepcopy
 
+from droughty.config import droughty_profile
 
 ## source vars
 
-path = os.path.expanduser('~')
-
-profile_pass = os.path.join(path,".droughty/profile.yaml")
-
-with open(profile_pass) as f:
-    lookml_config = yaml.load(f, Loader=yaml.FullLoader)
+profile_pass = droughty_profile
 
 def get_git_root(path):
 
